# Django routerific

Terrific routing for Django.

## Installation

```bash
pip install django-routerific
```

## Usage

```python
# urls.py
from routerific import route

urlpatterns = [
    # ...
]
```
